@@ -1,8 +1,13 @@
 import asyncio
 import collections
+import logging
 import multiprocessing
 import time
 
+from avocado.core.exceptions import TestFailFast
+
+LOG = logging.getLogger(__name__)
+
 
 class TaskStateMachine:
     """Represents all phases that a task can go through its life."""
@@ -47,6 +52,64 @@ class TaskStateMachine:
                            self._ready, self._started])
         return not pending
 
+    async def abort(self, status_reason=None):
+        """Abort all non-started tasks.
+
+        This method will move all non-started tasks to finished with a specific
+        reason.
+
+        :param status_reason: string reason. Optional.
+        """
+        await self.abort_queue('requested', status_reason)
+        await self.abort_queue('triaging', status_reason)
+        await self.abort_queue('ready', status_reason)
+
+    async def abort_queue(self, queue_name, status_reason=None):
+        """Abort all tasks inside a specific queue adding a status reason.
+
+        :param queue_name: a string with the queue name.
+        :param status_reason: string reason. Optional.
+        """
+        to_remove = []
+        async with self._lock:
+            queue = getattr(self, queue_name)
+            for _ in range(len(queue)):
+                if queue_name == 'requested':
+                    runtime_task = queue.popleft()
+                else:
+                    runtime_task = queue.pop(0)
+                to_remove.append(runtime_task)
+
+        if to_remove:
+            if status_reason:
+                LOG.debug('Aborting queue "%s" by finishing %u tasks: %s',
+                          queue_name, len(to_remove), status_reason)
+            else:
+                LOG.debug('Aborting queue "%s" by finishing %u tasks',
+                          queue_name, len(to_remove))
+
+        for task in to_remove:
+            await self.finish_task(task, status_reason)
+
+    async def finish_task(self, runtime_task, status_reason=None):
+        """Include a task to the finished queue with a specific reason.
+
+        This method is assuming that you have removed (pop) the task from the
+        original queue.
+
+        :param runtime_task: A running task object.
+        :param status_reason: string reason. Optional.
+        """
+        async with self._lock:
+            if runtime_task not in self.finished:
+                if status_reason:
+                    runtime_task.status = status_reason
+                    LOG.debug('Task "%s" finished: %s',
+                              runtime_task.task.identifier, status_reason)
+                else:
+                    LOG.debug('Task "%s" finished', runtime_task.task.identifier)
+                self.finished.append(runtime_task)
+
 
 class Worker:
 
@@ -61,6 +124,13 @@ class Worker:
             max_running = 2 * multiprocessing.cpu_count() - 1
         self._max_running = max_running
         self._task_timeout = task_timeout
+        LOG.debug("%s has been initialized", self)
+
+    def __repr__(self):
+        fmt = ('<Worker spawner="{}" max_triaging={} max_running={} '
+               'task_timeout={}>')
+        return fmt.format(self._spawner, self._max_triaging,
+                          self._max_running, self._task_timeout)
 
     async def bootstrap(self):
         """Reads from requested, moves into triaging."""
@@ -69,6 +139,8 @@ class Worker:
                 if len(self._state_machine.triaging) < self._max_triaging:
                     runtime_task = self._state_machine.requested.popleft()
                     self._state_machine.triaging.append(runtime_task)
+                    LOG.debug('Task "%s": requested -> triaging',
+                              runtime_task.task.identifier)
                 else:
                     return
         except IndexError:
@@ -84,7 +156,9 @@ class Worker:
                 for finished_rt_task in self._state_machine.finished:
                     if (finished_rt_task.task is task and
                             finished_rt_task.status == 'FAILED ON TRIAGE'):
-                        await fail_on_triage(runtime_task)
+
+                        await self._state_machine.finish_task(runtime_task,
+                                                              "FAILED ON TRIAGE")
                         return
                 # from here, this dependency `task` ran, so, let's check
                 # the its latest data in the status repo
@@ -99,16 +173,12 @@ class Worker:
                     return
                 # if this dependency task failed, skip the parent task
                 if latest_task_data['result'] not in ['pass']:
-                    await fail_on_triage(runtime_task)
+                    await self._state_machine.finish_task(runtime_task,
+                                                          "FAILED ON TRIAGE")
                     return
             # everything is fine!
             return True
 
-        async def fail_on_triage(runtime_task):
-            async with self._state_machine.lock:
-                self._state_machine.finished.append(runtime_task)
-                runtime_task.status = 'FAILED ON TRIAGE'
-
         try:
             async with self._state_machine.lock:
                 runtime_task = self._state_machine.triaging.pop(0)
@@ -120,8 +190,12 @@ class Worker:
             # check for requirements a task may have
             requirements_ok = (
                     await self._spawner.check_task_requirements(runtime_task))
-            if not requirements_ok:
-                await fail_on_triage(runtime_task)
+            if requirements_ok:
+                LOG.debug('Task "%s": requirements OK (will proceed to check '
+                          'dependencies)', runtime_task.task.identifier)
+            else:
+                await self._state_machine.finish_task(runtime_task,
+                                                      "FAILED ON TRIAGE")
                 return
 
         # handle task dependencies
@@ -141,6 +215,8 @@ class Worker:
             # successfully, so we can move on with the parent task
             dependencies_ok = await check_finished_dependencies(runtime_task)
             if not dependencies_ok:
+                LOG.debug('Task "%s" has failed dependencies',
+                          runtime_task.task.identifier)
                 return
 
         # the task is ready to run
@@ -169,16 +245,20 @@ class Worker:
             await asyncio.sleep(0.1)
             return
 
+        LOG.debug('Task "%s": about to be spawned with "%s"',
+                  runtime_task.task.identifier, self._spawner)
         start_ok = await self._spawner.spawn_task(runtime_task)
         if start_ok:
+            LOG.debug('Task "%s": spawned successfully',
+                      runtime_task.task.identifier)
             runtime_task.status = None
             if self._task_timeout is not None:
                 runtime_task.execution_timeout = time.monotonic() + self._task_timeout
             async with self._state_machine.lock:
                 self._state_machine.started.append(runtime_task)
         else:
-            async with self._state_machine.lock:
-                self._state_machine.finished.append(runtime_task)
+            await self._state_machine.finish_task(runtime_task,
+                                                  "FAILED ON START")
 
     async def monitor(self):
         """Reads from started, moves into finished."""
@@ -199,9 +279,13 @@ class Worker:
                 runtime_task.status = 'FINISHED'
             except asyncio.TimeoutError:
                 runtime_task.status = 'FINISHED W/ TIMEOUT'
+        failfast = runtime_task.task.runnable.config.get('run.failfast')
+        result_stats = self._state_machine._status_repo.result_stats
+        if failfast and 'fail' in result_stats:
+            await self._state_machine.abort("FAILFAST is enabled")
+            raise TestFailFast("Interrupting job (failfast).")
 
-        async with self._state_machine.lock:
-            self._state_machine.finished.append(runtime_task)
+        await self._state_machine.finish_task(runtime_task)
 
     async def run(self):
         """Pushes Tasks forward and makes them do something with their lives."""
