@@ -11,6 +11,7 @@ from avocado import Test
 from avocado.core import exit_codes
 from avocado.core.job import Job
 from avocado.core.suite import TestSuite
+from selftests.utils import python_module_available
 
 BOOLEAN_ENABLED = [True, 'true', 'on', 1]
 BOOLEAN_DISABLED = [False, 'false', 'off', 0]
@@ -200,9 +201,6 @@ def parse_args():
     parser.add_argument('--job-api',
                         help='Run job API checks',
                         action='store_true')
-    parser.add_argument('--disable-plugin-checks',
-                        help='Disable checks for a plugin (by directory name)',
-                        action='append', default=[])
     parser.add_argument('--nrunner-interface',
                         help='Run selftests/functional/test_nrunner_interface.py',
                         action='store_true')
@@ -218,8 +216,15 @@ def parse_args():
     parser.add_argument('--optional-plugins',
                         help='Run optional_plugins/*/tests/',
                         action='store_true')
+    parser.add_argument('--disable-plugin-checks',
+                        help='Disable checks for one or more plugins (by directory name), separated by comma',
+                        action='append', default=[])
 
-    return parser.parse_args()
+    arg = parser.parse_args()
+    # Make a list of strings instead of a list with a single string
+    if len(arg.disable_plugin_checks) > 0:
+        arg.disable_plugin_checks = arg.disable_plugin_checks[0].split(",")
+    return arg
 
 
 def create_suite_job_api(args):  # pylint: disable=W0621
@@ -233,7 +238,6 @@ def create_suite_job_api(args):  # pylint: disable=W0621
                                  % (__file__, test_class))
     config_check_archive_file_exists = {
         'run.references': [check_archive_file_exists],
-        'run.test_runner': 'runner',
         'run.dict_variants': [
             {'namespace': 'run.results.archive',
              'value': True,
@@ -252,7 +256,6 @@ def create_suite_job_api(args):  # pylint: disable=W0621
         % (__file__, test_class))
     config_check_category_directory_exists = {
         'run.references': [check_category_directory_exists],
-        'run.test_runner': 'runner',
         'run.dict_variants': [
             {'namespace': 'run.job_category',
              'value': 'foo',
@@ -270,7 +273,6 @@ def create_suite_job_api(args):  # pylint: disable=W0621
                               % (__file__, test_class))
     config_check_directory_exists = {
         'run.references': [check_directory_exists],
-        'run.test_runner': 'runner',
         'run.dict_variants': [
              {'namespace': 'sysinfo.collect.enabled',
               'value': True,
@@ -294,7 +296,6 @@ def create_suite_job_api(args):  # pylint: disable=W0621
                           % (__file__, test_class))
     config_check_file_content = {
         'run.references': [check_file_content],
-        'run.test_runner': 'runner',
         'run.dict_variants': [
             # finding the correct 'content' here is trick because any
             # simple string is added to the variant file name and is
@@ -374,7 +375,6 @@ def create_suite_job_api(args):  # pylint: disable=W0621
                          % (__file__, test_class))
     config_check_file_exists = {
         'run.references': [check_file_exists],
-        'run.test_runner': 'runner',
         'run.dict_variants': [
             {'namespace': 'job.run.result.json.enabled',
              'value': True,
@@ -429,7 +429,8 @@ def create_suite_job_api(args):  # pylint: disable=W0621
         ]
     }
 
-    if 'html' not in args.disable_plugin_checks:
+    if (python_module_available('avocado-framework-plugin-result-html') and
+            'html' not in args.disable_plugin_checks):
 
         config_check_file_exists['run.dict_variants'].append(
             {'namespace': 'job.run.result.html.enabled',
@@ -453,7 +454,6 @@ def create_suite_job_api(args):  # pylint: disable=W0621
                          % (__file__, test_class))
     config_check_output_file = {
         'run.references': [check_output_file],
-        'run.test_runner': 'runner',
         'run.dict_variants': [
             {'namespace': 'job.run.result.json.output',
              'file': 'custom.json',
@@ -470,7 +470,8 @@ def create_suite_job_api(args):  # pylint: disable=W0621
         ]
     }
 
-    if 'html' not in args.disable_plugin_checks:
+    if (python_module_available('avocado-framework-plugin-result-html') and
+            'html' not in args.disable_plugin_checks):
 
         config_check_output_file['run.dict_variants'].append(
             {'namespace': 'job.run.result.html.output',
@@ -487,7 +488,6 @@ def create_suite_job_api(args):  # pylint: disable=W0621
                                   % (__file__, test_class))
     config_check_tmp_directory_exists = {
         'run.references': [check_tmp_directory_exists],
-        'run.test_runner': 'runner',
         'run.dict_variants': [
             {'namespace': 'run.keep_tmp',
              'value': True,
@@ -510,7 +510,6 @@ def create_suites(args):  # pylint: disable=W0621
         'run.dict_variants': [
             {'runner': 'avocado-runner'},
             {'runner': 'avocado-runner-noop'},
-            {'runner': 'avocado-runner-exec'},
             {'runner': 'avocado-runner-exec-test'},
             {'runner': 'avocado-runner-python-unittest'},
             {'runner': 'avocado-runner-avocado-instrumented'},
@@ -518,11 +517,13 @@ def create_suites(args):  # pylint: disable=W0621
         ]
     }
 
-    if 'golang' not in args.disable_plugin_checks:
+    if (python_module_available('avocado-framework-plugin-golang') and
+            'golang' not in args.disable_plugin_checks):
         config_nrunner_interface['run.dict_variants'].append({
             'runner': 'avocado-runner-golang'})
 
-    if 'robot' not in args.disable_plugin_checks:
+    if (python_module_available('avocado-framework-plugin-robot') and
+            'robot' not in args.disable_plugin_checks):
         config_nrunner_interface['run.dict_variants'].append({
             'runner': 'avocado-runner-robot'})
 
