@@ -382,7 +382,13 @@ class LoaderTest(unittest.TestCase):
         path = os.path.join(os.path.dirname(os.path.dirname(__file__)),
                             '.data', 'safeloader', 'data', 'dont_detect_non_avocado.py')
         tests = self.loader.discover(path)
-        self._check_discovery([], tests)
+        exps = [(test.PythonUnittest,
+                 'dont_detect_non_avocado.StaticallyNotAvocadoTest.test'),
+                (test.PythonUnittest,
+                 'dont_detect_non_avocado.NotTest.test2'),
+                (test.PythonUnittest,
+                 'dont_detect_non_avocado.NotTest.test')]
+        self._check_discovery(exps, tests)
 
     def test_infinite_recurse(self):
         """Checks we don't crash on infinite recursion"""
